@@ -390,11 +390,24 @@ class FeedManager(gobject.GObject):
             subs_response = urllib2.urlopen(subs_request)
 
             doc = minidom.parse(subs_response)
-            nodes = doc.getElementsByTagName('object')[1:]
+            # The xml looks like this
+            # <object>
+            #    <list name="subscriptions">
+            #       <object><string name="id">feed/http://somefeed.com</string>....</object>
+            #       <object><string name="id">feed/http://someotherfeed.com</string>....</object>
+            #    </list>
+            # <object>
+            nodes = doc.documentElement.childNodes[0].childNodes
             for node in nodes:
-                element = node.getElementsByTagName("string")
-                feed = element[0].firstChild.data
-                urls.append(feed[len('feed/'):])
+                feed_url = node.firstChild.firstChild.data
+                # Google allows also some other kind of
+                # subscriptions. Skip them for the moment. I saw for
+                # example feeds like
+                # <string name="id">webfeed/someidreturnedbygoogle</string>
+                # <string name="id">user/someuserid/label/SomeLabel</string>
+                if feed_url.startswith('feed/'):
+                    print 'Importing: ' + feed_url[5:]
+                    urls.append(feed_url[5:])
         except:
             pass
 
@@ -560,6 +573,9 @@ class FeedManager(gobject.GObject):
 
             for node in nodesEntries:
                 entry_link = node.getElementsByTagName('link')[0].attributes['href'].value
+                if not node.getElementsByTagName('source')[0].getAttribute('gr:stream-id').startswith('feed/'):
+                    continue
+
                 feed_source = node.getElementsByTagName('source')[0].getElementsByTagName('link')[0].attributes['href'].value
                 if not feed_source in unread_dict:
                     unread_dict[feed_source] = [ entry_link ]
@@ -624,6 +640,12 @@ class FeedManager(gobject.GObject):
             return
 
         new_feed_data = ReSiStanceFeedDict(feedparser.parse(url), sync)
+
+        # 200 == OK, and 3xx are redirections
+        if new_feed_data.status!=200 and new_feed_data.status/100 != 3:
+            self._safe_callback(callback, None, None, user_data)
+            return
+
         self.feed_data_list.append(new_feed_data)
 
         if 'link' in new_feed_data.feed:
